==> haskell-xmlgen-0.6.2.2-186.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-I5Qi2dEfHXWIRPGSeYTad2
key:                  xmlgen-0.6.2.2-I5Qi2dEfHXWIRPGSeYTad2
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  de14d67de40aa173e5190d145f478746
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-I5Qi2dEfHXWIRPGSeYTad2
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xmlgen-0.6.2.2-187-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xmlgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmlgen
version:              0.6.2.2
visibility:           public
id:                   xmlgen-0.6.2.2-IDi4BuTIjhtF4dZMRAUNc3
key:                  xmlgen-0.6.2.2-IDi4BuTIjhtF4dZMRAUNc3
license:              BSD-3-Clause
maintainer:           Stefan Wehr <wehr@factisresearch.com>
author:
    Stefan Wehr, Stefan Schmidt, Johannes Weiss, David Leuschner

synopsis:             Fast XML generation library
description:          Library for high-performance XML generation.
category:             Text, XML
abi:                  8c52bbba032a5388e914a26a14820a97
exposed:              True
exposed-modules:      Text.XML.Generator
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmlgen-0.6.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xmlgen
hs-libraries:         HSxmlgen-0.6.2.2-IDi4BuTIjhtF4dZMRAUNc3
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-xmlgen/html/xmlgen.haddock
haddock-html:         /usr/share/doc/haskell-xmlgen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
